![](docs/_static/logo.png)

A Python package for: [__mu__]tation [__s__]pectrum [__h__]istory [__i__]nference

![build and test](https://github.com/harrispopgen/mushi/workflows/build%20and%20test/badge.svg)
![Python package](https://github.com/harrispopgen/mushi/workflows/Python%20package/badge.svg)

#### See [documentation](https://harrispopgen.github.io/mushi) for install and usage information.

Pairs well with the package [`mutyper`](https://github.com/harrispopgen/mutyper), which assigns mutation types to SNPs in VCF files.
